display.setStatusBar(display.HiddenStatusBar)

local physics = require "physics"
physics.start()
physics.setGravity(9.81, 0)  -- 9.81 m/s*s in the positive x direction
physics.setScale(80)  -- 80 pixels per meter
physics.setDrawMode("normal")

-- Cutoff For Step 1

-- Create the bounds of the "arena"
local background = display.newImage("CourtBackground.png")
local score = display.newText("Score: 0", 50, 300)
score:setTextColor(0, 0, 0)
score.rotation = -90
score.size = 36
local floor = display.newRect(320, 0, 1, 480)
local lWall = display.newRect(0, 480, 320, 1)
local rWall = display.newRect(0, -1, 320, 1)
local ceiling = display.newRect(-1, 0, 1, 480)

staticMaterial = {density=2, friction=.3, bounce=.4}
physics.addBody(floor, "static", staticMaterial)
physics.addBody(lWall, "static", staticMaterial)
physics.addBody(rWall, "static", staticMaterial)
physics.addBody(ceiling, "static", staticMaterial)

-- Create the goal
local vertPost = display.newRect(110, 5, 210, 10)
vertPost:setFillColor(33, 33, 33)
local horizPost = display.newRect(110, 10, 10, 40)
horizPost:setFillColor(33, 33, 33)
local backboard = display.newRect(55, 50, 85, 5)
backboard:setFillColor(33, 33, 33)

physics.addBody(vertPost, "static", staticMaterial)
physics.addBody(horizPost, "static", staticMaterial)
physics.addBody(backboard, "static", staticMaterial)

--Create the Ball
local ball = display.newCircle(50, 200, 10)
ball:setFillColor(192, 99, 55)

physics.addBody(ball, {density=.8, friction=.3, bounce=.6, radius=10})

-- End step 2

local speedX = 0
local speedY = 0
local prevTime = 0
local prevX = 0
local prevY = 0

-- A basic function for dragging physics objects
local function drag( event )
	local ball = event.target
	
	local phase = event.phase
	if "began" == phase then
		display.getCurrentStage():setFocus( ball )

		-- Store initial position
		ball.x0 = event.x - ball.x
		ball.y0 = event.y - ball.y
		
		-- Make body type temporarily "kinematic" (to avoid gravitional forces)
		event.target.bodyType = "kinematic"
		
		-- Stop current motion, if any
		event.target:setLinearVelocity( 0, 0 )
		event.target.angularVelocity = 0

	else
		if "moved" == phase then
			ball.x = event.x - ball.x0
			ball.y = event.y - ball.y0
		elseif "ended" == phase or "cancelled" == phase then
			display.getCurrentStage():setFocus( nil )
			event.target.bodyType = "dynamic"
			ball:setLinearVelocity(speedX, speedY)
		end
	end

	-- Stop further propagation of touch event!
	return true
end

function trackVelocity(event) 
	local timePassed = event.time - prevTime
	prevTime = prevTime + timePassed
	
	speedX = (ball.x - prevX)/(timePassed/1000)
	speedY = (ball.y - prevY)/(timePassed/1000)

	prevX = ball.x
	prevY = ball.y
end

Runtime:addEventListener("enterFrame", trackVelocity)
ball:addEventListener("touch", drag)

--End Step 3

--Create the hoop and scoring mechanism
local rimBack = display.newRect(110, 55, 5, 7)
rimBack:setFillColor(207, 67, 4)
local rimFront = display.newRect(110, 92, 5, 3)
rimFront:setFillColor(207, 67, 4)
local rimMiddle = display.newRect(110, 62, 5, 30)
rimMiddle:setFillColor(207, 67, 4)

physics.addBody(rimBack, "static", staticMaterial)
physics.addBody(rimFront, "static", staticMaterial)

scoreCtr = 0
local lastGoalTime = 1000

function monitorScore(event) 
	if event.time - lastGoalTime > 500  then
		if ball.x > 103 and ball.x < 117 and ball.y > 62 and ball.y < 92 then
			scoreCtr = scoreCtr + 1
			print(score)
			lastGoalTime = event.time
			score.text = "Score: " .. scoreCtr
		end
	end
end
Runtime:addEventListener("enterFrame", monitorScore)